@@ -11,12 +11,8 @@
 
 import os
 
+
 def getFileSize(path):
-    """
-    #Func    :   获取文件大小       
-    #Param   :   path   [in] 文件路径
-    #Return  :   整数       
-    """
     try:
         if os.path.isfile(path) is False:
             return 0
@@ -24,13 +20,8 @@ def getFileSize(path):
     except:
         return 0
 
-def getFileContent(path, isBin = False):
-    """
-    #Func    :   获取文件全部内容   
-    #Param   :   path    [in] 文件路径
-    #Param   :   isBin   [in] 是否用二进制读取
-    #Return  :   整数
-    """
+
+def getFileContent(path, isBin=False):
     mode = 'r'
     if isBin:
         mode = 'rb'
@@ -39,7 +30,19 @@ def getFileContent(path, isBin = False):
         if size <= 0:
             return ""
         with open(path, mode) as fd:
-            content = fd.read(size) 
+            content = fd.read(size)
         return content
     except:
         return ""
+
+
+def write(path, content, mode):
+    try:
+        with open(path, mode) as fd:
+            fd.write(content)
+        return True
+    except Exception as e:
+        return False
+
+
+
