@@ -12,20 +12,16 @@
 import aigpy.netHelper as netHelper
 
 def getInfo(projectName):
-    """
-    #Func    :   获取pip上项目的信息                                                              
-    #Param   :   projectName      [in] 项目名                                                     
-    #Return  :   json or None                              
+    """Get project information from pypi
+    - Return: json or None                              
     """
     url = 'https://pypi.org/pypi/' + projectName + '/json'
     ret = netHelper.downloadJson(url,None)
     return ret
     
 def getLastVersion(projectName):
-    """
-    #Func    :   获取pip上项目的最新的版本号                                                                      
-    #Param   :   projectName      [in] 项目名                                                     
-    #Return  :   Err:None                               
+    """Get project version from pypi
+    - Return: str or None                              
     """
     try:
         ret = getInfo(projectName)
@@ -36,10 +32,8 @@ def getLastVersion(projectName):
         return None
 
 def getVersionList(projectName):
-    """
-    #Func    :   获取pip上项目的全部版本信息                                                                 
-    #Param   :   projectName      [in] 项目名                                                     
-    #Return  :   数组 or None                               
+    """Get project all versions from pypi
+    - Return: json or None                              
     """
     try:
         ret = getInfo(projectName)
